@@ -1,5 +1,5 @@
 /*
- * Copyright 2018 Bytes & Brains
+ * Copyright 2024 Bytes & Brains
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,17 @@
  */
 
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
-\echo Use "ALTER EXTENSION h3 UPDATE TO '3.4.0'" to load this file. \quit
+\echo Use "ALTER EXTENSION h3 UPDATE TO '4.1.4'" to load this file. \quit
 
-DROP FUNCTION IF EXISTS h3_degs_to_rads(float);
-DROP FUNCTION IF EXISTS h3_rads_to_degs(float);
+CREATE OR REPLACE FUNCTION
+    h3index_recv(internal) RETURNS h3index
+AS 'h3' LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
+CREATE OR REPLACE FUNCTION
+    h3index_send(h3index) RETURNS bytea
+AS 'h3' LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
+ALTER TYPE h3index SET (
+    RECEIVE = h3index_recv,
+    SEND    = h3index_send
+);
