@@ -1,5 +1,5 @@
 /*
- * Copyright 2022 Bytes & Brains
+ * Copyright 2023 Bytes & Brains
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,21 @@
  */
 
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
-\echo Use "ALTER EXTENSION h3_postgis UPDATE TO '4.0.2'" to load this file. \quit
+\echo Use "ALTER EXTENSION h3_postgis UPDATE TO '4.1.3'" to load this file. \quit
+
+--@ availability: 4.1.3
+CREATE OPERATOR @ (
+    PROCEDURE = h3_lat_lng_to_cell,
+    LEFTARG = geometry, RIGHTARG = integer
+);
+COMMENT ON OPERATOR @ (geometry, integer) IS
+  'Index geometry at specified resolution.';
+
+--@ availability: 4.1.3
+CREATE OPERATOR @ (
+    PROCEDURE = h3_lat_lng_to_cell,
+    LEFTARG = geography, RIGHTARG = integer
+);
+COMMENT ON OPERATOR @ (geography, integer) IS
+  'Index geography at specified resolution.';
 
--- no changes
